
import com.jagacy.Key;
import com.jagacy.Session3270;
import com.jagacy.util.JagacyException;
import com.jagacy.util.JagacyProperties;
import com.jagacy.util.Logger;

/*
 * Copyright (c) 2005-2006 Jagacy Software.  All Rights Reserved.
 */

/**
 * This class uses fields to retrieve the first 5 java copyrights from the
 * Library of Congress.
 * 
 * @author Robert M. Preston
 *  
 */
public class Example3 extends Session3270 {

    private JagacyProperties props;

    private Logger logger;

    private Example3() throws JagacyException {
        super("example3");
        props = getProperties();
        logger = getLogger();
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.jagacy.Session3270#logon()
     */
    protected boolean logon() throws JagacyException {
        // Notice that you don't have to prefix each property with 'example3'.
        // Jagacy will do this for you. But, you do have to prefix the
        // entries in the property file.
        boolean success = waitForField("logon.wait", "logon.timeout.seconds");
        if (!success) {
            logger.fatal("Not main screen");
        }

        return success;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.jagacy.Session3270#logoff()
     */
    protected void logoff() throws JagacyException {
        writeField("logoff1.entry");
        writeKey(Key.ENTER_WAIT);
        waitForChange("logoff.timeout.seconds");

        // Intermediate screen that occurs sometimes.
        // Use a 0 timeout to just poll.
        if (waitForField("intermediate.wait", 0)) {
            writeKey(Key.ENTER_WAIT);
            waitForChange("logoff.timeout.seconds");
        }

        if (waitForField("logon.wait", "logoff.timeout.seconds")) {
            writeField("main.entry", props.get("main.entry.endValue"));
            writeKey(Key.ENTER_WAIT);
            waitForField("logoff2.wait", "logoff.timeout.seconds");
        }

        writeField("logoff2.entry");
        writeKey(Key.ENTER_WAIT);
        waitForChange("logoff.timeout.seconds");
    }

    /**
     * Retrieves the first 5 Java copyrights and writes them to System.out.
     * 
     * @throws JagacyException If an error occurs.
     */
    private void getJavaCopyrights() throws JagacyException {
        writeField("main.entry");
        writeKey(Key.ENTER_WAIT);
        
        if (!waitForField("notice.wait", "notice.timeout.seconds")) {
            logger.fatal("Not notice screen");
            return;
        }
        writeField("notice.entry");
        writeKey(Key.ENTER_WAIT);
        
        if (!waitForField("copyright.wait", "copyright.timeout.seconds")) {
            logger.fatal("Not copyright screen");
            return;
        }
        writeField("copyright.entry");
        writeKey(Key.ENTER_WAIT);
        
        if (!waitForField("monograph.wait", "monograph.timeout.seconds")) {
            logger.fatal("Not monograph screen");
            return;
        }
        writeField("monograph.entry", "java");
        writeKey(Key.ENTER_WAIT);
        
        waitForChange("data.timeout.seconds");
        if (!waitForField("data.wait", "data.timeout.seconds")) {
            logger.fatal("Not data screen");
            return;
        }

        String text = readField("data");
        for (int width = getWidth(); true;) {
            System.out.println(text.substring(0, width));
            text = text.substring(width);
            if (text.equals("")) {
                break;
            }
        }
    }

    /**
     * Print exception(s) to System.err.
     * @param e JagacyException
     */
    private static void printExceptions(JagacyException e) {
        System.err.println(e.getMessage());
        if (e.hasException()) {
            System.err.println(e.getException().getMessage());
        }
    }

    public static void main(String[] args) {
        Example3 example = null;
        try {
            example = new Example3();
            example.open();
            example.getJavaCopyrights();
            example.close();
        } catch (JagacyException e) {
            printExceptions(e);
            if (example != null) {
                example.abort();
            }
        }
        
        if ((example != null) && example.props.getBoolean("window", false)) {
            // Swing requires this if window is enabled.
            System.exit(0);
        }
    }
}